@@ -23,6 +23,7 @@ from .misc import norm_pic, get_step
 
 #https://pytorch.org/vision/0.8/_modules/torchvision/models/alexnet.html
 class AlexNet(nn.Module):
+    ''' Class to define the basic network architecture '''     
     def __init__(self, num_classes: int = 1, dropout: float = 0.5) -> None:
         super().__init__()
         #_log_api_usage_once(self)
@@ -63,6 +64,23 @@ class AlexNet(nn.Module):
 def generate_STIFMap(dapi, collagen, name, step, models, 
                     mask=False, batch_size=100, square_side=224, save_dir=False):
 
+    '''
+    Main function for computing STIFMaps
+
+    Arguments:
+     - dapi: The path to the DAPI image to use
+     - collagen: The path to the collagen image to use
+     - name: The prefix to use for saving the predictions, if 'save_dir' is specified
+     - step: The step size to use between squares
+     - models: The list of trained networks to use for predictions
+     - mask: (Optional) The path to a 2D mask the same dimension as 'dapi' of zeros and ones that specifies regions to exclude when predicting stiffness 
+     - batch_size: How many squares should be evaluated by one model at once
+     - square_side: The side length of each square to evaluate in the model
+     - save_dir: Where to save the stiffness predictions, or 'False' if saving is not desired
+     
+    Returns: `generate_STIFMap` returns a 3D numpy array of the stiffness predictions for the 'dapi'/'collagen' images for each of the included models
+    '''
+
     device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
     print('Device is ' + str(device))
     # For each collagen-DAPI pair, generate the STIFMap for each model provided
@@ -240,7 +258,7 @@ def generate_STIFMap(dapi, collagen, name, step, models,
 
         # Save the predictions as a numpy array
         if save_dir != False:
-            np.save(save_dir + name + '_model_' + model_name + '.npy', z_out)
+            np.save(save_dir + '/' + name + '_model_' + model_name + '.npy', z_out)
 
     # Save memory
     del im
@@ -251,8 +269,25 @@ def generate_STIFMap(dapi, collagen, name, step, models,
     return np.array(out)
 
 def collagen_paint(dapi, collagen, z, name, step,
-                    mask=False, square_side=224, quantile=0.99,
-                    scale_percent=100, save_dir='/home/connor/Documents/STIFMaps/test/'):
+                    mask=False, square_side=224,
+                    scale_percent=100, save_dir=False):
+
+    '''
+    Pseudocolor the collagen image to indicate the predicted stiffness of the collagen fibers
+    
+    Arguments:
+     - dapi: The path to the DAPI image to use
+     - collagen: The path to the collagen image to use
+     - z: The stiffness prediction values computed above
+     - name: The prefix to use for saving the predictions, if 'save_dir' is specified
+     - step: The step size used between squares
+     - mask: (Optional) The path to a 2D mask the same dimension as 'dapi' of zeros and ones that specifies regions to exclude when coloring collagen 
+     - square_side: The side length of each square evaluated in the model
+     - scale_percent: An integer from 1-100 specifying how much to scale down the images if memory usage or runtime is too high. Note that a value of 100 means that the images will not be scaled down at all
+     - save_dir: Where to save the collagen-painted image, or 'False' if saving is not desired
+     
+    Returns: In addition to saving the collagen-painted image (if specified), `collagen_paint` returns an RGB image of the pseudocolored collagen
+    '''
 
     then = time.time()
     
@@ -326,7 +361,7 @@ def collagen_paint(dapi, collagen, z, name, step,
     dapi = norm_pic(dapi)
 
     
-    '''
+    
     #############################################################################
     ########################################## Downsample
     ############ (scale_percent can be used to downsample the image if the full image uses too much memory)
@@ -335,15 +370,12 @@ def collagen_paint(dapi, collagen, z, name, step,
     width = int(dapi.shape[1] * scale_percent / 100)
     height = int(dapi.shape[0] * scale_percent / 100)
     dim = (width, height)
-
     # Downsample the images
     dapi = cv2.resize(dapi, dim, interpolation = cv2.INTER_AREA)
     collagen = cv2.resize(collagen, dim, interpolation = cv2.INTER_AREA)
-    stain1 = cv2.resize(stain1, dim, interpolation = cv2.INTER_AREA)
-    stain2 = cv2.resize(stain2, dim, interpolation = cv2.INTER_AREA)
     znew = cv2.resize(znew, dim, interpolation = cv2.INTER_AREA)
     mask = cv2.resize(mask, dim, interpolation = cv2.INTER_AREA)
-    '''
+    
 
     
     
@@ -378,7 +410,7 @@ def collagen_paint(dapi, collagen, z, name, step,
     del znew_color
 
     if save_dir != False:
-        plt.imsave(save_dir + name + '_STIFMap.png', collagen_colored)
+        plt.imsave(save_dir + '/' + name + '_STIFMap.png', collagen_colored)
 
 
     ######### Save the colorbar
@@ -390,7 +422,7 @@ def collagen_paint(dapi, collagen, z, name, step,
     cbar = plt.colorbar(orientation="vertical", cax=cax)
     cbar.ax.set_ylabel('log(elasticity) (Pa)', fontsize=18)
     if save_dir != False:
-        plt.savefig(save_dir + name + "_colorbar.png")
+        plt.savefig(save_dir + '/' + name + "_colorbar.png")
     
     
     
@@ -403,7 +435,25 @@ def collagen_paint(dapi, collagen, z, name, step,
 
 
 def correlate_signals_with_stain(dapi, collagen, z, stain, step,
-                    mask=False, square_side=224, quantile=0.99):
+                    mask=False, square_side=224, 
+                    scale_percent=100, quantile=0.99):
+
+    '''
+    Given an additional staining image taken at the same region as the DAPI and collagen images, compute the correlation between the staining intensity and the intensity of collagen, DAPI, and predicted stiffness
+    
+    Arguments:
+     - dapi: The path to the DAPI image to use
+     - collagen: The path to the collagen image to use
+     - z: The stiffness prediction values computed above
+     - stain: The path to the staining image to use
+     - step: The step size used between squares
+     - mask: (Optional) The path to a 2D mask the same dimension as 'dapi' of zeros and ones that specifies regions to exclude when coloring collagen 
+     - square_side: The side length of each square evaluated in the model
+     - scale_percent: An integer from 1-100 specifying how much to scale down the images if memory usage or runtime is too high. Note that a value of 100 means that the images will not be scaled down at all
+     - quantile: A float between zero and one specifying the quantile of stain intensity of use for each percentile of DAPI/collagen/STIFMap intensity. See the manuscript for more details
+     
+    Returns: `correlate_signals_with_stain` returns the Spearman correlation values between the staining intensity and the intensity of DAPI, collagen, and stiffness predictions
+    '''
 
     then = time.time()
 
@@ -484,6 +534,21 @@ def correlate_signals_with_stain(dapi, collagen, z, stain, step,
     collagen = norm_pic(collagen)
     dapi = norm_pic(dapi)
 
+    #############################################################################
+    ########################################## Downsample
+    ############ (scale_percent can be used to downsample the image if the full image uses too much memory)
+    #############################################################################
+    # Find the new dimensions    
+    width = int(dapi.shape[1] * scale_percent / 100)
+    height = int(dapi.shape[0] * scale_percent / 100)
+    dim = (width, height)
+    # Downsample the images
+    dapi = cv2.resize(dapi, dim, interpolation = cv2.INTER_AREA)
+    collagen = cv2.resize(collagen, dim, interpolation = cv2.INTER_AREA)
+    stain = cv2.resize(stain, dim, interpolation = cv2.INTER_AREA)
+    znew = cv2.resize(znew, dim, interpolation = cv2.INTER_AREA)
+    mask = cv2.resize(mask, dim, interpolation = cv2.INTER_AREA)
+
     ########################################### Evaluate the correlations between different signals    
 
     dapi = dapi.flatten()
